private var surfaceMat: Material;
private var width:int = 300;
private var height:int = 300;
private var texture: Texture2D;
private var cells = new Array(width*height);
private var emptyCellColor: Color = new Color(0,0,0,0);
private var aliveCellColor: Color = new Color(1,1,1,1);

private var iteration = 0;

function OnGUI()
{
	GUI.Button(Rect(160,40,120,30),"");
	GUI.Label(Rect(180,45,120,30),"Iteration: " + iteration);	
}

function Start()
{
	surfaceMat = this.renderer.material;
	texture = new Texture2D(width,height);
	
	//initialise all cells to empty/dead
	for (y=0; y < this.height; ++y) 
	{
		for (x=0; x < this.width; ++x) 
		{
			texture.SetPixel (x, y, emptyCellColor);
		}
	}
	
	//draw on surface
	surfaceMat.mainTexture = texture;
	texture.Apply();
	
	Seed();
}

function Seed()
{
	for(var i = 0; i < 5000; i++)
	{
		texture.SetPixel(Random.Range(0,width),Random.Range(0,height), aliveCellColor);
	}
	texture.Apply();	
}

/*Conway's Game Of Life
   1. Any live cell with fewer than two live neighbours dies, as if caused by under-population.
   2. Any live cell with two or three live neighbours lives on to the next generation.
   3. Any live cell with more than three live neighbours dies, as if by overcrowding.
   4. Any dead cell with exactly three live neighbours becomes a live cell, as if by reproduction.
   */

function UpdateCell(x: int, y: int)
{
	var aliveNeighbours = 0;
	if(texture.GetPixel(x-1,y+1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x,y+1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x+1,y+1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x-1,y-1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x,y-1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x+1,y-1) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x-1,y) == aliveCellColor) aliveNeighbours++;
	if(texture.GetPixel(x+1,y) == aliveCellColor) aliveNeighbours++;
	
	if(aliveNeighbours < 2) texture.SetPixel(x, y, emptyCellColor);
	if(aliveNeighbours >= 3) texture.SetPixel(x, y, emptyCellColor);
	if(aliveNeighbours == 3) texture.SetPixel(x, y, aliveCellColor);
}

function Update () 
{
	for(var i = 0; i < 5000; i++)
	{	
		UpdateCell(Random.Range(1,width-1),Random.Range(1,height-1));
	}
	texture.Apply();
	iteration++;
}